@@ -16,7 +16,11 @@ class server_class():
         self.clustering = {'label':[], 'raw':[], 'center':[]}
 
     def assign_model(self, model):
-        self.model = model
+        try:
+            self.model.load_state_dict(model.state_dict())
+        except:
+            self.model = model
+        # self.model = deepcopy(model)
         self.model.to(self.device)
         try:
             self.model = torch.compile(self.model)
@@ -113,6 +117,7 @@ class server_class():
         kmeans = KMeans(n_clusters=K).fit(np.asarray(X), sample_weight= weight)
         labels = kmeans.labels_
         print(labels)
+        print([list(labels).count(i) for i in range(K)])
         for i in idlist:
             nodes[i].label = labels[i]
         self.clustering['label'].append(list(labels.astype(int)))
